summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJonathan Neidel <github@jneidel.com>2021-04-25 19:41:07 +0200
committerGitHub <noreply@github.com>2021-04-25 19:41:07 +0200
commit22fd919ce48e2ff8abb739d1bf31ba827d27fe1b (patch)
tree0b2831543b4b301a95de0b1ffb30ee35f84ea9a1
parent71970fa73cdcf760499274fc9666611272cd62bf (diff)
Fix separator between albums with the same name, to check for album artist instead of artist (#472)
-rw-r--r--CHANGELOG.md2
-rw-r--r--src/display.cpp4
2 files changed, 4 insertions, 2 deletions
diff --git a/CHANGELOG.md b/CHANGELOG.md
index c80c515b..531599e3 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,6 +1,8 @@
# ncmpcpp-0.10 (????-??-??)
* Add the configuration option `mpd_password`.
* Separate chunks of lyrics with a double newline.
+* Fix separator between albums with the same name, to check for album artist
+ instead of artist.
# ncmpcpp-0.9.2 (2021-01-24)
* Revert suppression of output of all external commands as that makes e.g album
diff --git a/src/display.cpp b/src/display.cpp
index 8a09c55d..4a52d8ce 100644
--- a/src/display.cpp
+++ b/src/display.cpp
@@ -92,9 +92,9 @@ void setProperties(NC::Menu<T> &menu, const MPD::Song &s, const SongList &list,
{
// Draw a separator when the next album is different than the current
// one. In case there are two albums with the same name, but a different
// artist, compare also artists.
separate_albums = next->song()->getAlbum() != s.getAlbum()
- || next->song()->getArtist() != s.getArtist();
+ || next->song()->getAlbumArtist() != s.getAlbumArtist();
}
}
}
@@ -92,9 +92,9 @@ void setProperties(NC::Menu<T> &menu, const MPD::Song &s, const SongList &list,
// Draw a separator when the next album is different than the current
// one. In case there are two albums with the same name, but a different
- // artist, compare also artists.
+ // album artist, compare also album artists.
separate_albums = next->song()->getAlbum() != s.getAlbum()